@@ -27,6 +27,10 @@
 #include <sys/prctl.h>
 #include "mte_user_helper.h"
 #endif
+#ifdef CONFIG_TCG
+#include "accel/tcg/cpu-mmu-index.h"
+#include "exec/target_page.h"
+#endif
 
 int aarch64_cpu_gdb_read_register(CPUState *cs, GByteArray *mem_buf, int n)
 {
@@ -116,10 +120,10 @@ int aarch64_gdb_set_fpu_reg(CPUState *cs, uint8_t *buf, int reg)
              * On the wire these are target-endian 128 bit values.
              * In the CPU state these are host-order uint64_t values
              * with the least-significant one first. This means they're
-             * the other way around for target_words_bigendian() (which is
+             * the other way around for target_big_endian() (which is
              * only true for us for aarch64_be-linux-user).
              */
-            if (target_words_bigendian()) {
+            if (target_big_endian()) {
                 q[1] = ldq_p(buf);
                 q[0] = ldq_p(buf + 8);
             } else{
@@ -203,7 +207,7 @@ int aarch64_gdb_set_sve_reg(CPUState *cs, uint8_t *buf, int reg)
     {
         int vq, len = 0;
         for (vq = 0; vq < cpu->sve_max_vq; vq++) {
-            if (target_words_bigendian()) {
+            if (target_big_endian()) {
                 env->vfp.zregs[reg].d[vq * 2 + 1] = ldq_p(buf);
                 buf += 8;
                 env->vfp.zregs[reg].d[vq * 2] = ldq_p(buf);
